/*
Copyright (c) 2007-2009, Yusuke Yamamoto
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Yusuke Yamamoto nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY Yusuke Yamamoto ``AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL Yusuke Yamamoto BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
package com.fitbit.api;

import com.fitbit.api.client.http.Response;

import java.util.List;

public class FitbitAPIException extends Exception {
    private int statusCode = -1;
    private static final long serialVersionUID = -2623309261327598087L;
    private List<FitbitApiError> apiErrors;

    public FitbitAPIException(String msg) {
        super(msg);
    }

    public FitbitAPIException(Exception cause) {
        super(cause);
    }

    public FitbitAPIException(String msg, int statusCode) {
        super(msg);
        this.statusCode = statusCode;

    }

    public FitbitAPIException(String msg, Exception cause) {
        super(msg, cause);
    }

    public FitbitAPIException(String msg, Exception cause, int statusCode) {
        super(msg, cause);
        this.statusCode = statusCode;

    }

    public FitbitAPIException(String cause, Response res) throws FitbitAPIException {
        this(cause + '\n' + res.asString(), res.getStatusCode());
        statusCode = res.getStatusCode();
        apiErrors = FitbitApiError.constructFitbitApiErrorList(res);
    }

    public int getStatusCode() {
        return statusCode;
    }

    public List<FitbitApiError> getApiErrors() {
        return apiErrors;
    }
}